@@ -182,6 +182,29 @@ class GradescopeClient:
         }
         self.last_res = self.submit_form(url, referer_url, data=payload, files=files)
         return self.last_res.ok
+
+    def set_manual_ag_config(self, class_id: str, assignment_id: str, image: str) -> bool:
+        if not self.logged_in:
+            print("You must be logged in to rebuild an autograder!")
+            return
+        base_url = f"https://www.gradescope.com"
+        location_url = f"/courses/{class_id}/assignments/{assignment_id}"
+        referer_url = base_url + location_url + "/configure_autograder"
+        url = base_url + location_url
+        token = self.get_token(referer_url, meta="csrf-token")
+        payload = {
+                "utf8": "✓",
+                "_method": "patch",
+                "authenticity_token": token,
+                "configuration": "manual",
+                # "autograder_zip": (file_name, open(file_name, 'rb'), 'text/plain'),
+                "assignment[image_name]": image,
+            }
+        files = {
+            "autograder_zip": ("", "")
+        }
+        self.last_res = self.submit_form(url, referer_url, data=payload, files=files)
+        return self.last_res.ok
         
     def ag_building_data(self, class_id: str, assignment_id: str):
         if not self.logged_in:
